#
# spec file for package deepin-movie
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?is_opensuse}
    %define  distribution  openSUSE-Edition
%else
    %define  distribution  SUSE-Edition
%endif

%define sover 0_1

Name:           deepin-movie
Version:        5.10.8
Release:        1.8
Summary:        Deepin Video Players
License:        GPL-3.0-or-later AND OpenSSL
Group:          Productivity/Multimedia/Video/Players
URL:            https://github.com/linuxdeepin/deepin-movie-reborn
Source:         https://github.com/linuxdeepin/deepin-movie-reborn/archive/%{version}/%{name}-reborn-%{version}.tar.gz
# PATCH-FIX-UPSTEAM Fix-library-link.patch hillwood@opensuse.org
# fix library link error and add this includedir for ffmpeg
Patch0:         Fix-library-link.patch
%ifarch aarch64
# PATCH-FIX-UPSTEAM fix-build-on-ARM.patch hillwood@opensuse.org
Patch1:         fix-build-on-ARM.patch
%endif
BuildRequires:  dtkcore >= 5.0.0
BuildRequires:  fdupes
BuildRequires:  libQt5Gui-private-headers-devel
%ifarch ppc ppc64 ppc64le s390 s390x
BuildRequires:  deepin-desktop-base
%else
BuildRequires:  deepin-manual
%endif
BuildRequires:  glslang-devel
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(dtkcore) >= 5.0.0
BuildRequires:  pkgconfig(dtkgui) >= 5.0.0
BuildRequires:  pkgconfig(dtkwidget) >= 5.0.0
BuildRequires:  pkgconfig(dvdnav)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(gsettings-qt)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libffmpegthumbnailer)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(mpv)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(xcb-aux)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-proto)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(mpris-qt5)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  cmake(Qt5MultimediaWidgets)
BuildRequires:  pkgconfig(dbusextended-qt5)
%if 0%{?suse_version} <= 1500
BuildRequires:  qtdbusextended-devel < 3.1.2
BuildRequires:  qtmpris-devel < 3.1.2
%endif
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The default media player for Deepin. QML is used to build its
graphical interface, combined with QtAV as its multimedia backend.

%package -n libdmr%{sover}
Summary:        Deepin Video Players
Group:          System/Libraries

%description -n libdmr%{sover}
libdmr is a library for accessing the Direct Rendering Manager on Linux, BSD and
other operating systems that support the ioctl interface, and for chipsets with
DRM memory manager, support for tracking relocations and buffers. libdmr is a
low-level library, typically used by graphics drivers such as the Mesa DRI and X
drivers.

%package devel
Summary:        Development tools for deepin movie
Group:          Development/Languages/C and C++
Requires:       libdmr%{sover} = %{version}

%description devel
The deepin-movie-devel package contains the header files and developer docs for
deepin movie.

%lang_package

%prep
%autosetup -p1 -n %{name}-reborn-%{version}
sed -i 's/Exec=deepin-movie/Exec=env QT_QPA_PLATFORMTHEME=deepin deepin-movie/g' %{name}.desktop
%if %{?suse_version} > 1500
sed -i 's/MPV_EVENT_TRACKS_CHANGED/MP_EVENT_TRACKS_CHANGED/g' src/backends/mpv/mpv_proxy.cpp
%endif

%build
%cmake -DCMAKE_BUILD_TYPE=Release \
       -DVERSION=%{version}-%{distribution}
%make_build

%install
%cmake_install

%fdupes %{buildroot}

%post -n libdmr%{sover} -p /sbin/ldconfig

%postun -n libdmr%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README.md HACKING.md CHANGELOG.md
%license LICENSE LICENSE.OpenSSL
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/deepin-manual/manual-assets/application/%{name}
%exclude %{_datadir}/%{name}/translations
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/glib-2.0/schemas/com.deepin.deepin-movie.gschema.xml

%files -n libdmr%{sover}
%defattr(-,root,root)
%{_libdir}/libdmr.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libdmr.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/libdmr

%files lang
%defattr(-,root,root)
%{_datadir}/%{name}/translations

%changelog
* Thu Aug 25 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.10.8
  * Support gstreamer
  * Fix bugs
- Drop drop-MPV_EVENT_TRACKS_CHANGED.patch, fix-mpv_opengl_init_params.patch,
  drop-setCanShowInUI.patch and fix-build-on-mpv-0_34_1.patch, fixed by
  Upstream
* Sat Jul  2 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.18
  * Support feiteng graphics card
  * Fix bugs
  * Optimzize wayland support
  * Update documents
* Thu Apr 14 2022 Hillwood Yang <hillwood@opensuse.org>
- Add drop-MPV_EVENT_TRACKS_CHANGED.patch, drop the api
- Add fix-mpv_opengl_init_params.patch，Upstream of MPV changed this api
* Thu Apr 14 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.8
  * Fix bugs
  * Add English document
  * Optimize hard decoding
- Add fix-build-on-mpv-0_34_1.patch
* Sat Jan 15 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.9.1
  * Fix bugs
  * Update manual documents
- Add drop-setCanShowInUI.patch
* Sun May 23 2021 Hillwood Yang <hillwood@opensuse.org>
- Stop owning directories provided by filesystem and other packages
  (every dir should only have one owner) (boo#1184786)
* Wed Apr 28 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.11
  * Fix bugs
  * Add help documents
  * Use mpris-qt5 and dbusextended-qt5
- Drop deepin-movie-add-qthelper.patch and libavformat-version-check.patch
  merged by upstream.
* Wed Apr 21 2021 Hillwood Yang <hillwood@opensuse.org>
- Add fix-build-on-ARM.patch
* Tue Feb  2 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.6.165
  * Opimize ui
- Drop deepin-movie-reborn-add-pkgconfig-check.patch, fixed by upsteam
- Add libavformat-version-check.patch, fixed build on new ffmpeg
- Add Fix-library-link.patch, fix library link error and add this
  includedir for ffmpeg
* Sat Jan 30 2021 Hillwood Yang <hillwood@opensuse.org>
- Drop deepin-movie-Qt-5_15.patch
* Thu Jun 25 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.6.29
  * Fix bug on aarch64
  * Fix bug(24212)
* Wed Jun 24 2020 Hillwood Yang <hillwood@opensuse.org>
- Add deepin-movie-Qt-5_15.patch
  * Support Qt 5.15
* Tue May  5 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.7.6.28
  * Use new dtk apis
* Fri Mar 20 2020 Hillwood Yang <hillwood@opensuse.org>
- Add deepin-movie-add-qthelper.patch.
  qthelper.hpp was removed from mpv project, move this api in this project
* Sun Aug  4 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.2.24.3
  * Fix dtk-settings tool path
  * Update translations
  * Support Qt 5.13.0, drop Fix-build-on-Qt-5_13_0.patch
  * fix no-return-in-nonvoid-function check, drop
    no-return-in-nonvoid-function.patch
* Tue Jul  9 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 3.2.24
  * Fix card0 may not enabled/usable
  * Should free xcb_query_pointer_reply return pointer
  * workaround for QTBUG-76114.
  * Missing settings item added. Fix crash on file open.
  * Thumbnail previewer caused dock show up
  * Remember last opened path
  * Drag and drop to load subtitle
  * Fix buttons not shwon in mini mode on arm64 platform
  * Fix can not toggle mini mode when window maximized
  * Fix don't sleep while playing
  * New subtitle font style
- Fix build on Qt 5.13.0, add Fix-build-on-Qt-5_13_0.patch
- Add OpenSSL license
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality and accuracy of description.
* Tue Jan  8 2019 hillwood@opensuse.org
- Split development package.
* Thu Dec 20 2018 hillwood@opensuse.org
- Update version to 3.2.17
  * Fix the window point not follow touch point on touch screen and
    enable hi-DPI
  * remove application name in titlebar
  * set the generic name to "Movie"
  * support auto translate the dekstop file
  * Deepin vendor support
  * support the recent file spec
  * support touch move window
  * no transifex
  * Fix build error with libavresample deprecated
  * Fix crash when press F1
  * refactor: use DApplication::handleHelpAction to open help document
  * remove the TitleBar right margin
  * fix(libdmr): bypass sub saving and compilation
  * add frame-by-frame navigation support
- Add no-return-in-nonvoid-function.patch, fix no-return-in-nonvoid-function
  check.
* Fri Dec  1 2017 hillwood@opensuse.org
- Update to 3.0.1
  * Use vaapi_egl opengl interop when possible
  * Support build with DTK_DMAN_PORTAL
  * Support dman activation from flatpak env
  * Make play state button clickable
  * Hide titlebar in fullscreen playback
  * Render HiDPI texture by QImageReader
  * Use QImageReader to render HiDPI images
  * Correct shape mask in non-composited mode
  * Make sub font size approximate pixel size
  * Update playlist geometry under flatpak env
  Fix bugs:
  * Check cookie before inhibit
  * Cookie should be unsigned int
  * Check and do UnInhibit when window closed
  * Pixmap take device ratio into account
  * Make toolbox more transparent
  * Scale fbo according to devicePixelRatio
  * Honor devicePixelRatio for pixmap rendering
  * Basic hdpi texture adaption
  * Support flatpak
  * Respect devicePixelRatio when move
  * Improve 4k playback by disable opengl-hq
  * Update svgs and more QImageReader migration
  * Potential crash when closing a smb shared video
- Split language package.
- Add deepin-movie-reborn-add-pkgconfig-check.patch, fix pkg check
* Thu Nov  2 2017 hillwood@opensuse.org
- Update to 2.9.94
  * Migrate to QML.
* Thu Sep 28 2017 hillwood@opensuse.org
- Update to 2.2.15
  * Not showing resize visual while resizing
  * Fix a typo: useage -> usage
  * Translate desktop file
  * remove deepin-util depend in control
* Mon Feb 20 2017 hillwood@opensuse.org
- Update to 2.2.11
  * Fix crash on opening empty folder.
  * Fix crash on Qt5.6
  * Update window buttons
  * Cherry pick some bugfixes from release/2.2.2
  * Base on QtAV.
* Sun Oct 18 2015 i@marguerite.su
- add patch: deepin-movie-QJSValue-not-iterable.patch
  * fix "TypeError: 'QJSValue' object is not iterable"
  * https://github.com/linuxdeepin/deepin-movie/issues/11
* Mon Aug  3 2015 i@marguerite.su
- initial version 2.2.2+git20150504.8344897
